.. list-table:: Variables from HRRR available in ufs2arco
   :widths: 18 50
   :header-rows: 1

   * - Variable
     - Long Name
   * - ``accum_sdwe``
     - Water equivalent of accumulated snow depth (deprecated) accumulated over forecast
   * - ``accum_tp``
     - Total Precipitation accumulated over forecast
   * - ``blh``
     - Boundary layer height
   * - ``cape``
     - Convective available potential energy
   * - ``cfrzr``
     - Categorical freezing rain
   * - ``cicep``
     - Categorical ice pellets
   * - ``cin``
     - Convective inhibition
   * - ``cpofp``
     - Percent frozen precipitation
   * - ``crain``
     - Categorical rain
   * - ``csnow``
     - Categorical snow
   * - ``d2m``
     - 2 metre dewpoint temperature
   * - ``gh``
     - Geopotential height
   * - ``gust``
     - Wind speed (gust)
   * - ``lsm``
     - Land-sea mask
   * - ``max_10si``
     - Time-maximum 10 metre wind speed
   * - ``mslma``
     - MSLP (MAPS System Reduction)
   * - ``orog``
     - Orography
   * - ``prate``
     - Precipitation rate
   * - ``prmsl``
     - Pressure reduced to MSL
   * - ``q``
     - Specific humidity
   * - ``refc``
     - Maximum/Composite radar reflectivity
   * - ``refd1000``
     - 1000 metre Derived radar reflectivity
   * - ``refd4000``
     - 4000 metre Derived radar reflectivity
   * - ``sde``
     - Snow depth
   * - ``sdswrf``
     - Surface downward short-wave radiation flux
   * - ``sdwe``
     - Water equivalent of accumulated snow depth (deprecated)
   * - ``sh2``
     - 2 metre specific humidity
   * - ``siconc``
     - Sea ice area fraction
   * - ``snowc``
     - Snow cover
   * - ``sp``
     - Surface pressure
   * - ``t``
     - Temperature
   * - ``t2m``
     - 2 metre temperature
   * - ``tcc``
     - Total Cloud Cover
   * - ``t_surface``
     - Temperature at surface
   * - ``u``
     - U component of wind
   * - ``u10``
     - 10 metre U wind component
   * - ``u80``
     - 80 metre U component of wind
   * - ``v``
     - V component of wind
   * - ``v10``
     - 10 metre V wind component
   * - ``v80``
     - 80 metre V component of wind
   * - ``veril``
     - Vertically-integrated liquid
   * - ``vgtyp``
     - Vegetation Type
   * - ``vis``
     - Visibility
   * - ``w``
     - Vertical velocity
